@@ -111,6 +111,7 @@ public class DebugFSLogicalStructure {
 
     /**
      * Create information about a view for given CAS.
+     * @param cas -
      */
     public ViewInfo(CAS cas) {
       this.cas = cas;
@@ -127,7 +128,7 @@ public class DebugFSLogicalStructure {
     }
 
     /**
-     * Return the sofa.
+     * @return the sofa.
      */
     public Object getSofa() {
       return cas.getSofa();
@@ -141,12 +142,6 @@ public class DebugFSLogicalStructure {
    * 
    * Includes the "label" of the index, and a ref to the CAS this index contents are in.
    * 
-   * @param cas
-   *          The CAS the index lives in.
-   * @param indexName
-   *          The name of the index to create the helper object for.
-   * @param type
-   *          The subtype to restrict the index to, <code>null</code> to use the index base type.
    */
   public static class IndexInfo {
     public String indexName;
@@ -159,6 +154,14 @@ public class DebugFSLogicalStructure {
       this(cas, indexName, null);
     }
 
+    /**
+    * @param cas
+    *          The CAS the index lives in.
+    * @param indexName
+    *          The name of the index to create the helper object for.
+    * @param type
+    *          The subtype to restrict the index to, <code>null</code> to use the index base type.
+    */          
     public IndexInfo(CAS cas, String indexName, Type type) {
       this.indexName = indexName;
       this.cas = cas;
@@ -333,7 +336,7 @@ public class DebugFSLogicalStructure {
   }
 
   private static FeatureStructure[] getIndexContents(FSIterator<? extends FeatureStructure> it) {
-    return (FeatureStructure[]) iteratorToArray(it, FeatureStructure.class);
+    return iteratorToArray(it, FeatureStructure.class);
   }
 
   private static FeatureStructure[] getIndexContents(FSIndex<? extends FeatureStructure> fsIndex) {
@@ -407,7 +410,7 @@ public class DebugFSLogicalStructure {
     Iterator<String> it = cas.getIndexRepository().getLabels();
     List<IndexInfo> ll = new ArrayList<IndexInfo>();
     while (it.hasNext()) {
-      ll.add(new IndexInfo(cas, (String) it.next()));
+      ll.add(new IndexInfo(cas, it.next()));
     }
     return ll.toArray(new IndexInfo[ll.size()]);
 
@@ -417,7 +420,7 @@ public class DebugFSLogicalStructure {
     Iterator<SofaFS> sofaIt = cas.getSofaIterator();
     List<ViewInfo> r = new ArrayList<ViewInfo>();
     while (sofaIt.hasNext()) {
-      SofaFS item = (SofaFS) sofaIt.next();
+      SofaFS item = sofaIt.next();
       CAS oCas = cas.getView(item);
       if (oCas != cas)
         r.add(new ViewInfo(oCas));
@@ -457,7 +460,7 @@ public class DebugFSLogicalStructure {
     }
     float[] floatArray = new float[list.size()];
     for (int i = 0; i < floatArray.length; i++) {
-      floatArray[i] = ((Float) list.get(i)).floatValue();
+      floatArray[i] = list.get(i).floatValue();
     }
     return floatArray;
   }
@@ -481,7 +484,7 @@ public class DebugFSLogicalStructure {
     }
     int[] intArray = new int[list.size()];
     for (int i = 0; i < intArray.length; i++) {
-      intArray[i] = ((Integer) list.get(i)).intValue();
+      intArray[i] = list.get(i).intValue();
     }
     return intArray;
   }
