@@ -192,8 +192,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Sets component's input/output capabilities
    * 
-   * @param Capability -
-   *          component capabilities
+   * @param aMetadata       component capabilities
    */
   public void setMetadata(ProcessingResourceMetaData aMetadata) {
     metadata = aMetadata;
@@ -365,8 +364,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Aggregate total bytes ingested by the CasProcessor.
    * 
-   * @param -
-   *          aBytesIn - number of ingested bytes
+   * @param aBytesIn - number of ingested bytes
    */
   public void addBytesIn(long aBytesIn) {
     bytesIn += aBytesIn;
@@ -385,7 +383,6 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Aggregate total bytes processed by this CasProcessor
    * 
-   * @return - number of bytes added to the Cas
    */
   public void addBytesOut(long aBytesOut) {
     bytesOut += aBytesOut;
@@ -394,8 +391,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Increment number of times the casProcessor was restarted due to failures
    * 
-   * @param -
-   *          aCount - restart count
+   * @param aCount - restart count
    */
   public void incrementRestartCount(int aCount) {
     restartCount += aCount;
@@ -404,8 +400,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Returns total number of all CasProcessor restarts.
    * 
-   * @param -
-   *          number of restarts
+   * @return number of restarts
    */
   public int getRestartCount() {
     return restartCount;
@@ -415,8 +410,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
    * Increments number of times CasProceesor failed analyzing Cas'es due to timeout or some other
    * problems
    * 
-   * @param -
-   *          aCount - failure count
+   * @param aCount - failure count
    */
   public void incrementRetryCount(int aCount) {
     retryCount += aCount;
@@ -434,8 +428,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Increment number of aborted Cas'es due to inability to process the Cas
    * 
-   * @param -
-   *          aCount - number of aborts while processing Cas'es
+   * @param aCount - number of aborts while processing Cas'es
    */
   public void incrementAbortCount(int aCount) {
     abortCount += aCount;
@@ -494,8 +487,7 @@ public class ProcessingContainer_Impl extends ProcessingContainer implements Run
   /**
    * Copies id of the last entity processed by the CasProcessor
    * 
-   * @param -
-   *          aEntityId - id of the entity
+   * @param aEntityId - id of the entity
    */
   public void setLastProcessedEntityId(String aEntityId) {
     processedEntityIds.push(aEntityId);
@@ -540,8 +532,7 @@ public Object getLastCas() {
   /**
    * Used when recovering from checkpoint, sets the total number of entities before CPE stopped.
    * 
-   * @param -
-   *          aProcessedCount - number of entities processed before CPE stopped
+   * @param aProcessedCount - number of entities processed before CPE stopped
    */
   public void setProcessed(long aProcessedCount) {
     processed = aProcessedCount;
@@ -592,7 +583,7 @@ public Object getLastCas() {
   /**
    * Returns true if maximum threshold for errors has been exceeded and the CasProcessor is
    * configured to force CPE shutdown. It looks at the value of the action attribute of the
-   * <errorRateThreshold> element in the cpe descriptor.
+   * &lt;errorRateThreshold&gt; element in the cpe descriptor.
    * 
    * @return - true if the CPE should stop processing, false otherwise
    */
@@ -626,7 +617,7 @@ public Object getLastCas() {
    * run, if it should disable the CasProcessor (and all its instances), or disregard the error and
    * continue.
    * 
-   * @apram aThrowable - exception to examine
+   * @param aThrowable - exception to examine
    * 
    * @exception AbortCPMException -
    *              force the CPE to stop processing
@@ -1009,7 +1000,7 @@ public Object getLastCas() {
         }
 
         if ((filterExpression.getOperand() == null
-                && filterExpression.getOperand().getOperand() == null && !exists)
+                || filterExpression.getOperand().getOperand() == null || !exists)
                 || // this means that the feature must exist in CAS
                 ("!".equals(filterExpression.getOperand().getOperand()) && exists)) // this
         // means
@@ -1071,7 +1062,7 @@ public Object getLastCas() {
 
   /**
    * Returns CasProcessor configuration object. This object represents xml configuration defined in
-   * the <casProcessor> section of the cpe descriptor.
+   * the &lt;casProcessor&gt; section of the cpe descriptor.
    * 
    * @return {@link CasProcessorConfiguration} instance
    */
@@ -1239,7 +1230,8 @@ public boolean isIntegrated() {
 
   /**
    * Determines if instances of CasProcessor managed by this container are abortable. Abortable
-   * CasProcessor's action attribute in the <errorRateThreshold> element has a value of 'disable'.
+   * CasProcessor's action attribute in the &lt;errorRateThreshold&gt; element has a value of
+   * 'disable'.
    * 
    * @return true if CasProcessor can be disabled
    */
@@ -1292,9 +1284,7 @@ public boolean isIntegrated() {
     return false;
   }
 
-  /**
-   * 
-   */
+  
   public boolean initialize(ResourceSpecifier aSpecifier, Map aAdditionalParams)
           throws ResourceInitializationException {
     try {
@@ -1501,7 +1491,7 @@ public boolean isIntegrated() {
   /**
    * Returns all stats aggregate during the CPM run
    * 
-   * @return
+   * @return a map of all stats aggregated during the CPM run
    */
   public HashMap getAllStats() {
     synchronized (statMap) {
@@ -1549,9 +1539,7 @@ public boolean isIntegrated() {
     return casProcessorPool;
   }
 
-  /**
-   * 
-   */
+  
   public void setSingleFencedService(boolean aSingleFencedInstance) {
     singleFencedInstance = aSingleFencedInstance;
   }
